# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/oracle.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/oracle/v1beta1/oracle.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x0e\n\x06Params:\x04\xe8\xa0\x1f\x01\"\xba\x01\n\x13\x43hainlinkPriceState\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12?\n\x0bprice_state\x18\x04 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"|\n\x16SetChainlinkPriceEvent\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"\xc9\x01\n\x0e\x42\x61ndPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12<\n\x04rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x03 \x01(\x04\x12\x12\n\nrequest_ID\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\x9d\x01\n\x11SetBandPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x04 \x01(\x04\x12\x12\n\nrequest_id\x18\x05 \x01(\x04\"\xb5\x01\n\x14SetBandIBCPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12>\n\x06prices\x18\x03 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x04 \x01(\x04\x12\x12\n\nrequest_id\x18\x05 \x01(\x04\x12\x11\n\tclient_id\x18\x06 \x01(\x03\"?\n\x16\x45ventBandIBCAckSuccess\x12\x12\n\nack_result\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\x03\"<\n\x14\x45ventBandIBCAckError\x12\x11\n\tack_error\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\x03\"0\n\x1b\x45ventBandIBCResponseTimeout\x12\x11\n\tclient_id\x18\x01 \x01(\x03\"{\n\x10GetReferenceData\x12\x19\n\x11\x62\x61se_quote_symbol\x18\x01 \x01(\t\x12\x17\n\x0f\x62\x61se_quote_rate\x18\x02 \x01(\t\x12\x18\n\x10last_update_base\x18\x03 \x01(\t\x12\x19\n\x11last_update_quote\x18\x04 \x01(\t\"b\n GrantBandOraclePrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08relayers\x18\x03 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"c\n!RevokeBandOraclePrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08relayers\x18\x03 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x80\x01\n!GrantPriceFeederPrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\r\n\x05quote\x18\x04 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x81\x01\n\"RevokePriceFeederPrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\r\n\x05quote\x18\x04 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"z\n\x0ePriceFeedState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\x12\x39\n\x0bprice_state\x18\x03 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\x12\x10\n\x08relayers\x18\x04 \x03(\t\",\n\rPriceFeedInfo\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\"O\n\x0ePriceFeedPrice\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x85\x01\n\x16SetPriceFeedPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x92\x01\n\x12\x43oinbasePriceState\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"y\n\x15SetCoinbasePriceEvent\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"\xa8\x01\n\nPriceState\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x63umulative_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\x96\x01\n\"AuthorizeBandOracleRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x42\n\x07request\x18\x03 \x01(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequestB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb6\x01\n\x1fUpdateBandOracleRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65lete_request_id\x18\x03 \x01(\x04\x12J\n\x15update_oracle_request\x18\x04 \x01(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8d\x01\n\x15\x45nableBandIBCProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x46\n\x0f\x62\x61nd_ibc_params\x18\x03 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x88\x02\n\x11\x42\x61ndOracleRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x04\x12\x18\n\x10oracle_script_id\x18\x02 \x01(\x03\x12\x15\n\x07symbols\x18\x03 \x03(\tB\x04\xc8\xde\x1f\x00\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0bprepare_gas\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\x08 \x01(\x04\"\x8d\x01\n\rBandIBCParams\x12\x18\n\x10\x62\x61nd_ibc_enabled\x18\x01 \x01(\x08\x12\x1c\n\x14ibc_request_interval\x18\x02 \x01(\x03\x12\x1a\n\x12ibc_source_channel\x18\x03 \x01(\t\x12\x13\n\x0bibc_version\x18\x04 \x01(\t\x12\x13\n\x0bibc_port_id\x18\x05 \x01(\t*\x91\x01\n\nOracleType\x12\x0f\n\x0bUnspecified\x10\x00\x12\x08\n\x04\x42\x61nd\x10\x01\x12\r\n\tPriceFeed\x10\x02\x12\x0c\n\x08\x43oinbase\x10\x03\x12\r\n\tChainlink\x10\x04\x12\t\n\x05Razor\x10\x05\x12\x07\n\x03\x44ia\x10\x06\x12\x08\n\x04\x41PI3\x10\x07\x12\x07\n\x03Uma\x10\x08\x12\x08\n\x04Pyth\x10\t\x12\x0b\n\x07\x42\x61ndIBC\x10\nBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])

_ORACLETYPE = _descriptor.EnumDescriptor(
  name='OracleType',
  full_name='injective.oracle.v1beta1.OracleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Band', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PriceFeed', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Coinbase', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Chainlink', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Razor', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Dia', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API3', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Uma', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Pyth', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BandIBC', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3490,
  serialized_end=3635,
)
_sym_db.RegisterEnumDescriptor(_ORACLETYPE)

OracleType = enum_type_wrapper.EnumTypeWrapper(_ORACLETYPE)
Unspecified = 0
Band = 1
PriceFeed = 2
Coinbase = 3
Chainlink = 4
Razor = 5
Dia = 6
API3 = 7
Uma = 8
Pyth = 9
BandIBC = 10



_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.oracle.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=135,
)


_CHAINLINKPRICESTATE = _descriptor.Descriptor(
  name='ChainlinkPriceState',
  full_name='injective.oracle.v1beta1.ChainlinkPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.oracle.v1beta1.ChainlinkPriceState.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.oracle.v1beta1.ChainlinkPriceState.answer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.ChainlinkPriceState.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.ChainlinkPriceState.price_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=324,
)


_SETCHAINLINKPRICEEVENT = _descriptor.Descriptor(
  name='SetChainlinkPriceEvent',
  full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent.answer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=450,
)


_BANDPRICESTATE = _descriptor.Descriptor(
  name='BandPriceState',
  full_name='injective.oracle.v1beta1.BandPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.BandPriceState.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='injective.oracle.v1beta1.BandPriceState.rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.BandPriceState.resolve_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_ID', full_name='injective.oracle.v1beta1.BandPriceState.request_ID', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.BandPriceState.price_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=654,
)


_SETBANDPRICEEVENT = _descriptor.Descriptor(
  name='SetBandPriceEvent',
  full_name='injective.oracle.v1beta1.SetBandPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetBandPriceEvent.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.SetBandPriceEvent.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetBandPriceEvent.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.SetBandPriceEvent.resolve_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.SetBandPriceEvent.request_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=814,
)


_SETBANDIBCPRICEEVENT = _descriptor.Descriptor(
  name='SetBandIBCPriceEvent',
  full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.symbols', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prices', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.prices', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.resolve_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.request_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.client_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=998,
)


_EVENTBANDIBCACKSUCCESS = _descriptor.Descriptor(
  name='EventBandIBCAckSuccess',
  full_name='injective.oracle.v1beta1.EventBandIBCAckSuccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack_result', full_name='injective.oracle.v1beta1.EventBandIBCAckSuccess.ack_result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.EventBandIBCAckSuccess.client_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1063,
)


_EVENTBANDIBCACKERROR = _descriptor.Descriptor(
  name='EventBandIBCAckError',
  full_name='injective.oracle.v1beta1.EventBandIBCAckError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack_error', full_name='injective.oracle.v1beta1.EventBandIBCAckError.ack_error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.EventBandIBCAckError.client_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1125,
)


_EVENTBANDIBCRESPONSETIMEOUT = _descriptor.Descriptor(
  name='EventBandIBCResponseTimeout',
  full_name='injective.oracle.v1beta1.EventBandIBCResponseTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.EventBandIBCResponseTimeout.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1175,
)


_GETREFERENCEDATA = _descriptor.Descriptor(
  name='GetReferenceData',
  full_name='injective.oracle.v1beta1.GetReferenceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_quote_symbol', full_name='injective.oracle.v1beta1.GetReferenceData.base_quote_symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_quote_rate', full_name='injective.oracle.v1beta1.GetReferenceData.base_quote_rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_base', full_name='injective.oracle.v1beta1.GetReferenceData.last_update_base', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_quote', full_name='injective.oracle.v1beta1.GetReferenceData.last_update_quote', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1300,
)


_GRANTBANDORACLEPRIVILEGEPROPOSAL = _descriptor.Descriptor(
  name='GrantBandOraclePrivilegeProposal',
  full_name='injective.oracle.v1beta1.GrantBandOraclePrivilegeProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.GrantBandOraclePrivilegeProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.GrantBandOraclePrivilegeProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.GrantBandOraclePrivilegeProposal.relayers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1400,
)


_REVOKEBANDORACLEPRIVILEGEPROPOSAL = _descriptor.Descriptor(
  name='RevokeBandOraclePrivilegeProposal',
  full_name='injective.oracle.v1beta1.RevokeBandOraclePrivilegeProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.RevokeBandOraclePrivilegeProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.RevokeBandOraclePrivilegeProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.RevokeBandOraclePrivilegeProposal.relayers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1501,
)


_GRANTPRICEFEEDERPRIVILEGEPROPOSAL = _descriptor.Descriptor(
  name='GrantPriceFeederPrivilegeProposal',
  full_name='injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal.base', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal.quote', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal.relayers', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1632,
)


_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL = _descriptor.Descriptor(
  name='RevokePriceFeederPrivilegeProposal',
  full_name='injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal.base', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal.quote', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal.relayers', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1635,
  serialized_end=1764,
)


_PRICEFEEDSTATE = _descriptor.Descriptor(
  name='PriceFeedState',
  full_name='injective.oracle.v1beta1.PriceFeedState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.PriceFeedState.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.PriceFeedState.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.PriceFeedState.price_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.PriceFeedState.relayers', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1766,
  serialized_end=1888,
)


_PRICEFEEDINFO = _descriptor.Descriptor(
  name='PriceFeedInfo',
  full_name='injective.oracle.v1beta1.PriceFeedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.PriceFeedInfo.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.PriceFeedInfo.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1890,
  serialized_end=1934,
)


_PRICEFEEDPRICE = _descriptor.Descriptor(
  name='PriceFeedPrice',
  full_name='injective.oracle.v1beta1.PriceFeedPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceFeedPrice.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1936,
  serialized_end=2015,
)


_SETPRICEFEEDPRICEEVENT = _descriptor.Descriptor(
  name='SetPriceFeedPriceEvent',
  full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.base', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.quote', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2151,
)


_COINBASEPRICESTATE = _descriptor.Descriptor(
  name='CoinbasePriceState',
  full_name='injective.oracle.v1beta1.CoinbasePriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='injective.oracle.v1beta1.CoinbasePriceState.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.CoinbasePriceState.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='injective.oracle.v1beta1.CoinbasePriceState.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective.oracle.v1beta1.CoinbasePriceState.value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.CoinbasePriceState.price_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2300,
)


_SETCOINBASEPRICEEVENT = _descriptor.Descriptor(
  name='SetCoinbasePriceEvent',
  full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2302,
  serialized_end=2423,
)


_PRICESTATE = _descriptor.Descriptor(
  name='PriceState',
  full_name='injective.oracle.v1beta1.PriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceState.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_price', full_name='injective.oracle.v1beta1.PriceState.cumulative_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.PriceState.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2426,
  serialized_end=2594,
)


_AUTHORIZEBANDORACLEREQUESTPROPOSAL = _descriptor.Descriptor(
  name='AuthorizeBandOracleRequestProposal',
  full_name='injective.oracle.v1beta1.AuthorizeBandOracleRequestProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.AuthorizeBandOracleRequestProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.AuthorizeBandOracleRequestProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='injective.oracle.v1beta1.AuthorizeBandOracleRequestProposal.request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2597,
  serialized_end=2747,
)


_UPDATEBANDORACLEREQUESTPROPOSAL = _descriptor.Descriptor(
  name='UpdateBandOracleRequestProposal',
  full_name='injective.oracle.v1beta1.UpdateBandOracleRequestProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.UpdateBandOracleRequestProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.UpdateBandOracleRequestProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_request_id', full_name='injective.oracle.v1beta1.UpdateBandOracleRequestProposal.delete_request_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_oracle_request', full_name='injective.oracle.v1beta1.UpdateBandOracleRequestProposal.update_oracle_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2750,
  serialized_end=2932,
)


_ENABLEBANDIBCPROPOSAL = _descriptor.Descriptor(
  name='EnableBandIBCProposal',
  full_name='injective.oracle.v1beta1.EnableBandIBCProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.oracle.v1beta1.EnableBandIBCProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.oracle.v1beta1.EnableBandIBCProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_ibc_params', full_name='injective.oracle.v1beta1.EnableBandIBCProposal.band_ibc_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2935,
  serialized_end=3076,
)


_BANDORACLEREQUEST = _descriptor.Descriptor(
  name='BandOracleRequest',
  full_name='injective.oracle.v1beta1.BandOracleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.BandOracleRequest.request_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='injective.oracle.v1beta1.BandOracleRequest.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.BandOracleRequest.symbols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='injective.oracle.v1beta1.BandOracleRequest.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='injective.oracle.v1beta1.BandOracleRequest.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='injective.oracle.v1beta1.BandOracleRequest.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='injective.oracle.v1beta1.BandOracleRequest.prepare_gas', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='injective.oracle.v1beta1.BandOracleRequest.execute_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3079,
  serialized_end=3343,
)


_BANDIBCPARAMS = _descriptor.Descriptor(
  name='BandIBCParams',
  full_name='injective.oracle.v1beta1.BandIBCParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='band_ibc_enabled', full_name='injective.oracle.v1beta1.BandIBCParams.band_ibc_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_request_interval', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_request_interval', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_source_channel', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_source_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_version', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_port_id', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_port_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3346,
  serialized_end=3487,
)

_CHAINLINKPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_BANDPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_PRICEFEEDSTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_COINBASEPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_AUTHORIZEBANDORACLEREQUESTPROPOSAL.fields_by_name['request'].message_type = _BANDORACLEREQUEST
_UPDATEBANDORACLEREQUESTPROPOSAL.fields_by_name['update_oracle_request'].message_type = _BANDORACLEREQUEST
_ENABLEBANDIBCPROPOSAL.fields_by_name['band_ibc_params'].message_type = _BANDIBCPARAMS
_BANDORACLEREQUEST.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['ChainlinkPriceState'] = _CHAINLINKPRICESTATE
DESCRIPTOR.message_types_by_name['SetChainlinkPriceEvent'] = _SETCHAINLINKPRICEEVENT
DESCRIPTOR.message_types_by_name['BandPriceState'] = _BANDPRICESTATE
DESCRIPTOR.message_types_by_name['SetBandPriceEvent'] = _SETBANDPRICEEVENT
DESCRIPTOR.message_types_by_name['SetBandIBCPriceEvent'] = _SETBANDIBCPRICEEVENT
DESCRIPTOR.message_types_by_name['EventBandIBCAckSuccess'] = _EVENTBANDIBCACKSUCCESS
DESCRIPTOR.message_types_by_name['EventBandIBCAckError'] = _EVENTBANDIBCACKERROR
DESCRIPTOR.message_types_by_name['EventBandIBCResponseTimeout'] = _EVENTBANDIBCRESPONSETIMEOUT
DESCRIPTOR.message_types_by_name['GetReferenceData'] = _GETREFERENCEDATA
DESCRIPTOR.message_types_by_name['GrantBandOraclePrivilegeProposal'] = _GRANTBANDORACLEPRIVILEGEPROPOSAL
DESCRIPTOR.message_types_by_name['RevokeBandOraclePrivilegeProposal'] = _REVOKEBANDORACLEPRIVILEGEPROPOSAL
DESCRIPTOR.message_types_by_name['GrantPriceFeederPrivilegeProposal'] = _GRANTPRICEFEEDERPRIVILEGEPROPOSAL
DESCRIPTOR.message_types_by_name['RevokePriceFeederPrivilegeProposal'] = _REVOKEPRICEFEEDERPRIVILEGEPROPOSAL
DESCRIPTOR.message_types_by_name['PriceFeedState'] = _PRICEFEEDSTATE
DESCRIPTOR.message_types_by_name['PriceFeedInfo'] = _PRICEFEEDINFO
DESCRIPTOR.message_types_by_name['PriceFeedPrice'] = _PRICEFEEDPRICE
DESCRIPTOR.message_types_by_name['SetPriceFeedPriceEvent'] = _SETPRICEFEEDPRICEEVENT
DESCRIPTOR.message_types_by_name['CoinbasePriceState'] = _COINBASEPRICESTATE
DESCRIPTOR.message_types_by_name['SetCoinbasePriceEvent'] = _SETCOINBASEPRICEEVENT
DESCRIPTOR.message_types_by_name['PriceState'] = _PRICESTATE
DESCRIPTOR.message_types_by_name['AuthorizeBandOracleRequestProposal'] = _AUTHORIZEBANDORACLEREQUESTPROPOSAL
DESCRIPTOR.message_types_by_name['UpdateBandOracleRequestProposal'] = _UPDATEBANDORACLEREQUESTPROPOSAL
DESCRIPTOR.message_types_by_name['EnableBandIBCProposal'] = _ENABLEBANDIBCPROPOSAL
DESCRIPTOR.message_types_by_name['BandOracleRequest'] = _BANDORACLEREQUEST
DESCRIPTOR.message_types_by_name['BandIBCParams'] = _BANDIBCPARAMS
DESCRIPTOR.enum_types_by_name['OracleType'] = _ORACLETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

ChainlinkPriceState = _reflection.GeneratedProtocolMessageType('ChainlinkPriceState', (_message.Message,), {
  'DESCRIPTOR' : _CHAINLINKPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ChainlinkPriceState)
  })
_sym_db.RegisterMessage(ChainlinkPriceState)

SetChainlinkPriceEvent = _reflection.GeneratedProtocolMessageType('SetChainlinkPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETCHAINLINKPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetChainlinkPriceEvent)
  })
_sym_db.RegisterMessage(SetChainlinkPriceEvent)

BandPriceState = _reflection.GeneratedProtocolMessageType('BandPriceState', (_message.Message,), {
  'DESCRIPTOR' : _BANDPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandPriceState)
  })
_sym_db.RegisterMessage(BandPriceState)

SetBandPriceEvent = _reflection.GeneratedProtocolMessageType('SetBandPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETBANDPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetBandPriceEvent)
  })
_sym_db.RegisterMessage(SetBandPriceEvent)

SetBandIBCPriceEvent = _reflection.GeneratedProtocolMessageType('SetBandIBCPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETBANDIBCPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetBandIBCPriceEvent)
  })
_sym_db.RegisterMessage(SetBandIBCPriceEvent)

EventBandIBCAckSuccess = _reflection.GeneratedProtocolMessageType('EventBandIBCAckSuccess', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBANDIBCACKSUCCESS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EventBandIBCAckSuccess)
  })
_sym_db.RegisterMessage(EventBandIBCAckSuccess)

EventBandIBCAckError = _reflection.GeneratedProtocolMessageType('EventBandIBCAckError', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBANDIBCACKERROR,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EventBandIBCAckError)
  })
_sym_db.RegisterMessage(EventBandIBCAckError)

EventBandIBCResponseTimeout = _reflection.GeneratedProtocolMessageType('EventBandIBCResponseTimeout', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBANDIBCRESPONSETIMEOUT,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EventBandIBCResponseTimeout)
  })
_sym_db.RegisterMessage(EventBandIBCResponseTimeout)

GetReferenceData = _reflection.GeneratedProtocolMessageType('GetReferenceData', (_message.Message,), {
  'DESCRIPTOR' : _GETREFERENCEDATA,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.GetReferenceData)
  })
_sym_db.RegisterMessage(GetReferenceData)

GrantBandOraclePrivilegeProposal = _reflection.GeneratedProtocolMessageType('GrantBandOraclePrivilegeProposal', (_message.Message,), {
  'DESCRIPTOR' : _GRANTBANDORACLEPRIVILEGEPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.GrantBandOraclePrivilegeProposal)
  })
_sym_db.RegisterMessage(GrantBandOraclePrivilegeProposal)

RevokeBandOraclePrivilegeProposal = _reflection.GeneratedProtocolMessageType('RevokeBandOraclePrivilegeProposal', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEBANDORACLEPRIVILEGEPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.RevokeBandOraclePrivilegeProposal)
  })
_sym_db.RegisterMessage(RevokeBandOraclePrivilegeProposal)

GrantPriceFeederPrivilegeProposal = _reflection.GeneratedProtocolMessageType('GrantPriceFeederPrivilegeProposal', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPRICEFEEDERPRIVILEGEPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.GrantPriceFeederPrivilegeProposal)
  })
_sym_db.RegisterMessage(GrantPriceFeederPrivilegeProposal)

RevokePriceFeederPrivilegeProposal = _reflection.GeneratedProtocolMessageType('RevokePriceFeederPrivilegeProposal', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPRICEFEEDERPRIVILEGEPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.RevokePriceFeederPrivilegeProposal)
  })
_sym_db.RegisterMessage(RevokePriceFeederPrivilegeProposal)

PriceFeedState = _reflection.GeneratedProtocolMessageType('PriceFeedState', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDSTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedState)
  })
_sym_db.RegisterMessage(PriceFeedState)

PriceFeedInfo = _reflection.GeneratedProtocolMessageType('PriceFeedInfo', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedInfo)
  })
_sym_db.RegisterMessage(PriceFeedInfo)

PriceFeedPrice = _reflection.GeneratedProtocolMessageType('PriceFeedPrice', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDPRICE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedPrice)
  })
_sym_db.RegisterMessage(PriceFeedPrice)

SetPriceFeedPriceEvent = _reflection.GeneratedProtocolMessageType('SetPriceFeedPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETPRICEFEEDPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetPriceFeedPriceEvent)
  })
_sym_db.RegisterMessage(SetPriceFeedPriceEvent)

CoinbasePriceState = _reflection.GeneratedProtocolMessageType('CoinbasePriceState', (_message.Message,), {
  'DESCRIPTOR' : _COINBASEPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.CoinbasePriceState)
  })
_sym_db.RegisterMessage(CoinbasePriceState)

SetCoinbasePriceEvent = _reflection.GeneratedProtocolMessageType('SetCoinbasePriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETCOINBASEPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetCoinbasePriceEvent)
  })
_sym_db.RegisterMessage(SetCoinbasePriceEvent)

PriceState = _reflection.GeneratedProtocolMessageType('PriceState', (_message.Message,), {
  'DESCRIPTOR' : _PRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceState)
  })
_sym_db.RegisterMessage(PriceState)

AuthorizeBandOracleRequestProposal = _reflection.GeneratedProtocolMessageType('AuthorizeBandOracleRequestProposal', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZEBANDORACLEREQUESTPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.AuthorizeBandOracleRequestProposal)
  })
_sym_db.RegisterMessage(AuthorizeBandOracleRequestProposal)

UpdateBandOracleRequestProposal = _reflection.GeneratedProtocolMessageType('UpdateBandOracleRequestProposal', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBANDORACLEREQUESTPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.UpdateBandOracleRequestProposal)
  })
_sym_db.RegisterMessage(UpdateBandOracleRequestProposal)

EnableBandIBCProposal = _reflection.GeneratedProtocolMessageType('EnableBandIBCProposal', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEBANDIBCPROPOSAL,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EnableBandIBCProposal)
  })
_sym_db.RegisterMessage(EnableBandIBCProposal)

BandOracleRequest = _reflection.GeneratedProtocolMessageType('BandOracleRequest', (_message.Message,), {
  'DESCRIPTOR' : _BANDORACLEREQUEST,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandOracleRequest)
  })
_sym_db.RegisterMessage(BandOracleRequest)

BandIBCParams = _reflection.GeneratedProtocolMessageType('BandIBCParams', (_message.Message,), {
  'DESCRIPTOR' : _BANDIBCPARAMS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandIBCParams)
  })
_sym_db.RegisterMessage(BandIBCParams)


DESCRIPTOR._options = None
_PARAMS._options = None
_CHAINLINKPRICESTATE.fields_by_name['answer']._options = None
_CHAINLINKPRICESTATE.fields_by_name['price_state']._options = None
_SETCHAINLINKPRICEEVENT.fields_by_name['answer']._options = None
_BANDPRICESTATE.fields_by_name['rate']._options = None
_BANDPRICESTATE.fields_by_name['price_state']._options = None
_SETBANDPRICEEVENT.fields_by_name['price']._options = None
_SETBANDIBCPRICEEVENT.fields_by_name['prices']._options = None
_GRANTBANDORACLEPRIVILEGEPROPOSAL._options = None
_REVOKEBANDORACLEPRIVILEGEPROPOSAL._options = None
_GRANTPRICEFEEDERPRIVILEGEPROPOSAL._options = None
_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL._options = None
_PRICEFEEDPRICE.fields_by_name['price']._options = None
_SETPRICEFEEDPRICEEVENT.fields_by_name['price']._options = None
_COINBASEPRICESTATE.fields_by_name['price_state']._options = None
_SETCOINBASEPRICEEVENT.fields_by_name['price']._options = None
_PRICESTATE.fields_by_name['price']._options = None
_PRICESTATE.fields_by_name['cumulative_price']._options = None
_AUTHORIZEBANDORACLEREQUESTPROPOSAL.fields_by_name['request']._options = None
_AUTHORIZEBANDORACLEREQUESTPROPOSAL._options = None
_UPDATEBANDORACLEREQUESTPROPOSAL._options = None
_ENABLEBANDIBCPROPOSAL.fields_by_name['band_ibc_params']._options = None
_ENABLEBANDIBCPROPOSAL._options = None
_BANDORACLEREQUEST.fields_by_name['symbols']._options = None
_BANDORACLEREQUEST.fields_by_name['fee_limit']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.gov.v1beta1 import tx_pb2 as cosmos_dot_gov_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the bank Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubmitProposal = channel.unary_unary(
                '/cosmos.gov.v1beta1.Msg/SubmitProposal',
                request_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgSubmitProposal.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgSubmitProposalResponse.FromString,
                )
        self.Vote = channel.unary_unary(
                '/cosmos.gov.v1beta1.Msg/Vote',
                request_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVote.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteResponse.FromString,
                )
        self.VoteWeighted = channel.unary_unary(
                '/cosmos.gov.v1beta1.Msg/VoteWeighted',
                request_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteWeighted.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteWeightedResponse.FromString,
                )
        self.Deposit = channel.unary_unary(
                '/cosmos.gov.v1beta1.Msg/Deposit',
                request_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgDeposit.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgDepositResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the bank Msg service.
    """

    def SubmitProposal(self, request, context):
        """SubmitProposal defines a method to create new proposal given a content.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vote(self, request, context):
        """Vote defines a method to add a vote on a specific proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteWeighted(self, request, context):
        """VoteWeighted defines a method to add a weighted vote on a specific proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposit(self, request, context):
        """Deposit defines a method to add deposit on a specific proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SubmitProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitProposal,
                    request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgSubmitProposal.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgSubmitProposalResponse.SerializeToString,
            ),
            'Vote': grpc.unary_unary_rpc_method_handler(
                    servicer.Vote,
                    request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVote.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteResponse.SerializeToString,
            ),
            'VoteWeighted': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteWeighted,
                    request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteWeighted.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteWeightedResponse.SerializeToString,
            ),
            'Deposit': grpc.unary_unary_rpc_method_handler(
                    servicer.Deposit,
                    request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgDeposit.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgDepositResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.gov.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the bank Msg service.
    """

    @staticmethod
    def SubmitProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Msg/SubmitProposal',
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgSubmitProposal.SerializeToString,
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgSubmitProposalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Vote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Msg/Vote',
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVote.SerializeToString,
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VoteWeighted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Msg/VoteWeighted',
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteWeighted.SerializeToString,
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgVoteWeightedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deposit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Msg/Deposit',
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgDeposit.SerializeToString,
            cosmos_dot_gov_dot_v1beta1_dot_tx__pb2.MsgDepositResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import asyncio
import logging
import grpc

import pyinjective.proto.exchange.injective_spot_exchange_rpc_pb2 as spot_exchange_rpc_pb
import pyinjective.proto.exchange.injective_spot_exchange_rpc_pb2_grpc as spot_exchange_rpc_grpc
import pyinjective.proto.exchange.injective_derivative_exchange_rpc_pb2 as derivative_exchange_rpc_pb
import pyinjective.proto.exchange.injective_derivative_exchange_rpc_pb2_grpc as derivative_exchange_rpc_grpc

from decimal import *
from pyinjective.constant import Network

metadata_template = """[{}]
description = '{} {} {}'
base = {}
quote = {}
min_price_tick_size = {}
min_display_price_tick_size = {}
min_quantity_tick_size = {}
min_display_quantity_tick_size = {}

"""

symbol_template = """[{}]
peggy_denom = {}
decimals = {}

"""

testnet_denom_output = ''
mainnet_denom_output = ''

async def fetch_denom(network) -> str:
    denom_output = ''
    symbols = {}

    # fetch meta data for spot markets
    async with grpc.aio.insecure_channel(network.grpc_exchange_endpoint) as channel:
        spot_exchange_rpc = spot_exchange_rpc_grpc.InjectiveSpotExchangeRPCStub(channel)
        status = 'active'
        mresp = await spot_exchange_rpc.Markets(spot_exchange_rpc_pb.MarketsRequest(market_status=status))
        for market in mresp.markets:
            # append symbols to dict
            if market.base_token_meta.SerializeToString() != '':
                symbols[market.base_token_meta.symbol] = (market.base_denom, market.base_token_meta.decimals)

            if market.quote_token_meta.SerializeToString() != '':
                symbols[market.quote_token_meta.symbol] = (market.base_denom, market.quote_token_meta.decimals)

            # format into ini entry
            min_display_price_tick_size = float(market.min_price_tick_size) / pow(10, market.quote_token_meta.decimals -  market.base_token_meta.decimals)
            min_display_quantity_tick_size = float(market.min_quantity_tick_size) / pow(10, market.base_token_meta.decimals)
            config = metadata_template.format(
                market.market_id,
                network.string().capitalize(), 'Spot', market.ticker,
                market.base_token_meta.decimals,
                market.quote_token_meta.decimals,
                market.min_price_tick_size,
                min_display_price_tick_size,
                market.min_quantity_tick_size,
                min_display_quantity_tick_size
            )
            denom_output += config

    # fetch meta data for derivative markets
    async with grpc.aio.insecure_channel(network.grpc_exchange_endpoint) as channel:
        derivative_exchange_rpc = derivative_exchange_rpc_grpc.InjectiveDerivativeExchangeRPCStub(channel)
        status = 'active'
        mresp = await derivative_exchange_rpc.Markets(derivative_exchange_rpc_pb.MarketsRequest(market_status=status))
        for market in mresp.markets:
            # append symbols to dict
            if market.quote_token_meta.SerializeToString() != '':
                symbols[market.quote_token_meta.symbol] = (market.quote_denom, market.quote_token_meta.decimals)

            # format into ini entry
            min_display_price_tick_size = float(market.min_price_tick_size) / pow(10, market.quote_token_meta.decimals)
            config = metadata_template.format(
                market.market_id,
                network.string().capitalize(), 'Derivative', market.ticker,
                0,
                market.quote_token_meta.decimals,
                market.min_price_tick_size,
                min_display_price_tick_size,
                market.min_quantity_tick_size,
                market.min_quantity_tick_size
            )
            denom_output += config

    # format into ini entry
    for key in symbols:
        peggy_id, decimals = symbols[key]
        symbol = symbol_template.format(key, peggy_id, decimals)
        denom_output += symbol

    return denom_output

async def main() -> None:
    devnet = Network.devnet()
    data = await fetch_denom(devnet)
    with open("denoms_devnet.ini", "w") as text_file:
        text_file.write(data)

    testnet = Network.testnet(node="sentry0")
    data = await fetch_denom(testnet)
    with open("denoms_testnet.ini", "w") as text_file:
        text_file.write(data)

    mainnet = Network.mainnet(node="sentry0")
    data = await fetch_denom(mainnet)
    with open("denoms_mainnet.ini", "w") as text_file:
        text_file.write(data)

if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO)
    asyncio.get_event_loop().run_until_complete(main())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/genutil/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/genutil/v1beta1/genesis.proto',
  package='cosmos.genutil.v1beta1',
  syntax='proto3',
  serialized_options=b'Z,github.com/cosmos/cosmos-sdk/x/genutil/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$cosmos/genutil/v1beta1/genesis.proto\x12\x16\x63osmos.genutil.v1beta1\x1a\x14gogoproto/gogo.proto\"X\n\x0cGenesisState\x12H\n\x07gen_txs\x18\x01 \x03(\x0c\x42\x37\xfa\xde\x1f\x18\x65ncoding/json.RawMessage\xea\xde\x1f\x06gentxs\xf2\xde\x1f\ryaml:\"gentxs\"B.Z,github.com/cosmos/cosmos-sdk/x/genutil/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='cosmos.genutil.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gen_txs', full_name='cosmos.genutil.v1beta1.GenesisState.gen_txs', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\037\030encoding/json.RawMessage\352\336\037\006gentxs\362\336\037\ryaml:\"gentxs\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=174,
)

DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.genutil.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.genutil.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['gen_txs']._options = None
# @@protoc_insertion_point(module_scope)
